@@ -77,6 +77,7 @@ static void                 _pango_fc_font_get_scale_factors (PangoFont     *fon
                                                               double        *y_scale);
 static void                 pango_fc_font_get_matrix      (PangoFont        *font,
                                                            PangoMatrix      *matrix);
+static int                  pango_fc_font_get_absolute_size (PangoFont        *font);
 
 #define PANGO_FC_FONT_LOCK_FACE(font)	(PANGO_FC_FONT_GET_CLASS (font)->lock_face (font))
 #define PANGO_FC_FONT_UNLOCK_FACE(font)	(PANGO_FC_FONT_GET_CLASS (font)->unlock_face (font))
@@ -112,6 +113,7 @@ pango_fc_font_class_init (PangoFcFontClass *class)
   pclass->is_hinted = _pango_fc_font_is_hinted;
   pclass->get_scale_factors = _pango_fc_font_get_scale_factors;
   pclass->get_matrix = pango_fc_font_get_matrix;
+  pclass->get_absolute_size = pango_fc_font_get_absolute_size;
 
   /**
    * PangoFcFont:pattern:
@@ -300,6 +302,18 @@ pango_fc_font_describe_absolute (PangoFont *font)
   return desc;
 }
 
+static int
+pango_fc_font_get_absolute_size (PangoFont *font)
+{
+  PangoFcFont *fcfont = (PangoFcFont *)font;
+  double size;
+
+  if (FcPatternGetDouble (fcfont->font_pattern, FC_PIXEL_SIZE, 0, &size) == FcResultMatch)
+    return (int) (size * PANGO_SCALE);
+
+  return 0;
+}
+
 static PangoCoverage *
 pango_fc_font_get_coverage (PangoFont     *font,
 			    PangoLanguage *language G_GNUC_UNUSED)
@@ -959,25 +973,26 @@ pango_fc_font_create_hb_font (PangoFont *font)
   if (key)
     {
       const FcPattern *pattern = pango_fc_font_key_get_pattern (key);
-      const PangoMatrix *matrix;
-      PangoMatrix matrix2;
+      const PangoMatrix *ctm;
+      PangoMatrix font_matrix;
       PangoGravity gravity;
       FcMatrix fc_matrix, *fc_matrix_val;
       double x, y;
       int i;
 
-      matrix = pango_fc_font_key_get_matrix (key);
-      pango_matrix_get_font_scale_factors (matrix, &x_scale_inv, &y_scale_inv);
+      ctm = pango_fc_font_key_get_matrix (key);
+      pango_matrix_get_font_scale_factors (ctm, &x_scale_inv, &y_scale_inv);
 
       FcMatrixInit (&fc_matrix);
       for (i = 0; FcPatternGetMatrix (pattern, FC_MATRIX, i, &fc_matrix_val) == FcResultMatch; i++)
         FcMatrixMultiply (&fc_matrix, &fc_matrix, fc_matrix_val);
 
-      matrix2.xx = fc_matrix.xx;
-      matrix2.yx = fc_matrix.yx;
-      matrix2.xy = fc_matrix.xy;
-      matrix2.yy = fc_matrix.yy;
-      pango_matrix_get_font_scale_factors (&matrix2, &x, &y);
+      font_matrix.xx = fc_matrix.xx;
+      font_matrix.yx = fc_matrix.yx;
+      font_matrix.xy = fc_matrix.xy;
+      font_matrix.yy = fc_matrix.yy;
+
+      pango_matrix_get_font_scale_factors (&font_matrix, &x, &y);
 
       x_scale_inv /= x;
       y_scale_inv /= y;
@@ -1117,8 +1132,9 @@ _pango_fc_font_get_scale_factors (PangoFont *font,
                                   double    *y_scale)
 {
   PangoFcFont *fcfont = PANGO_FC_FONT (font);
+  PangoFcFontPrivate *priv = fcfont->priv;
 
-  pango_matrix_get_font_scale_factors (&fcfont->matrix, x_scale, y_scale);
+  pango_matrix_get_font_scale_factors (pango_fc_font_key_get_matrix (priv->key), x_scale, y_scale);
 }
 
 static void
