@@ -137,12 +137,24 @@ pango_hb_font_get_nominal_glyph (hb_font_t      *font,
   if (hb_font_get_nominal_glyph (context->parent, unicode, glyph))
     return TRUE;
 
-  /* HarfBuzz knows how to synthesize spaces, so never replace them
-   * with unknown glyphs, but we do need to tell HarfBuzz that the
-   * font does not have a glyph.
+  /* HarfBuzz knows how to synthesize other spaces from 0x20, so never
+   * replace them with unknown glyphs, just tell HarfBuzz that we don't
+   * have a glyph.
+   *
+   * For 0x20, on the other hand, we need to pretend that we have a glyph
+   * and rely on our glyph extents code to provide a reasonable width for
+   * PANGO_GET_UNKNOWN_WIDTH (0x20).
    */
   if (g_unichar_type (unicode) == G_UNICODE_SPACE_SEPARATOR)
-    return FALSE;
+    {
+      if (unicode == 0x20)
+        {
+          *glyph = PANGO_GET_UNKNOWN_GLYPH (0x20);
+          return TRUE;
+        }
+
+      return FALSE;
+    }
 
   *glyph = PANGO_GET_UNKNOWN_GLYPH (unicode);
 
@@ -162,11 +174,16 @@ pango_hb_font_get_glyph_h_advance (hb_font_t      *font,
                                    void           *user_data G_GNUC_UNUSED)
 {
   PangoHbShapeContext *context = (PangoHbShapeContext *) font_data;
-  PangoRectangle logical;
 
-  pango_font_get_glyph_extents (context->font, glyph, NULL, &logical);
+  if (glyph & PANGO_GLYPH_UNKNOWN_FLAG)
+    {
+      PangoRectangle logical;
 
-  return logical.width;
+      pango_font_get_glyph_extents (context->font, glyph, NULL, &logical);
+      return logical.width;
+    }
+
+  return hb_font_get_glyph_h_advance (context->parent, glyph);
 }
 
 static hb_position_t
@@ -176,14 +193,16 @@ pango_hb_font_get_glyph_v_advance (hb_font_t      *font,
                                    void           *user_data G_GNUC_UNUSED)
 {
   PangoHbShapeContext *context = (PangoHbShapeContext *) font_data;
-  PangoRectangle logical;
 
-  pango_font_get_glyph_extents (context->font, glyph, NULL, &logical);
+  if (glyph & PANGO_GLYPH_UNKNOWN_FLAG)
+    {
+      PangoRectangle logical;
 
-  if (hb_font_get_glyph_v_advance (context->parent, glyph) < 0)
-    return - logical.height;
-  else
-    return logical.height;
+      pango_font_get_glyph_extents (context->font, glyph, NULL, &logical);
+      return logical.height;
+    }
+
+  return hb_font_get_glyph_v_advance (context->parent, glyph);
 }
 
 static hb_bool_t
@@ -194,16 +213,22 @@ pango_hb_font_get_glyph_extents (hb_font_t          *font,
                                  void               *user_data G_GNUC_UNUSED)
 {
   PangoHbShapeContext *context = (PangoHbShapeContext *) font_data;
-  PangoRectangle ink;
 
-  pango_font_get_glyph_extents (context->font, glyph, &ink, NULL);
+  if (glyph & PANGO_GLYPH_UNKNOWN_FLAG)
+    {
+      PangoRectangle ink;
 
-  extents->x_bearing = ink.x;
-  extents->y_bearing = ink.y;
-  extents->width     = ink.width;
-  extents->height    = ink.height;
+      pango_font_get_glyph_extents (context->font, glyph, &ink, NULL);
 
-  return TRUE;
+      extents->x_bearing = ink.x;
+      extents->y_bearing = ink.y;
+      extents->width     = ink.width;
+      extents->height    = ink.height;
+
+      return TRUE;
+    }
+
+  return hb_font_get_glyph_extents (context->parent, glyph, extents);
 }
 
 static hb_font_t *
